greenheart.simulation.technologies.offshore.floating\_platform
==============================================================

.. automodule:: greenheart.simulation.technologies.offshore.floating_platform

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      calc_substructure_mass_and_cost
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      FloatingPlatformDesign
      FloatingPlatformInstallation
   
   

   
   
   



